<h1 align="center">
<img src="https://raw.githubusercontent.com/pranav-bhamidipati/circuitree/main/logo.png" width="300">
</h1><br>

Biochemical circuit design using Monte Carlo tree search

## Installation

```pip install circuitree```

## Getting Started

[Getting started tutorial](https://githubtocolab.com/pranav-bhamidipati/circuitree-tutorial/blob/main/src/tutorial-1-getting-started.ipynb). 

See the [`circuitree-tutorial`](https://github.com/pranav-bhamidipati/circuitree-tutorial) repo for additional tutorials and example scripts.

## Documentation

API docs coming soon


© 2024 Pranav Bhamidipati
Logo © 2024 Inna-Marie Strazhnik 
